@@ -1,7 +1,7 @@
 package Pcore::Handle::DBI::Query::ORDER_BY;
 
 use Pcore -const, -class;
-use Pcore::Lib::Scalar qw[is_ref is_plain_arrayref];
+use Pcore::Util::Scalar qw[is_ref is_plain_arrayref];
 
 has _buf => ( required => 1 );    # ArrayRef
 
@@ -34,7 +34,7 @@ sub get_query ( $self, $dbh, $final, $i ) {
         }
     }
 
-    return @sql ? ( 'ORDER BY ' . join( q[, ], @sql ), undef ) : ( undef, undef );
+    return @sql ? ( 'ORDER BY ' . join( ', ', @sql ), undef ) : ( undef, undef );
 }
 
 1;
